@@ -2,7 +2,7 @@
 Date         : 2022-10-25 17:21:52
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2022-10-28 14:30:26
+LastEditTime : 2022-10-28 16:11:02
 LastEditors  : BDFD
 Description  : 
 FilePath     : \execdata\preprocess.py
@@ -22,11 +22,11 @@ def encode(df):
             df[column] = lable.fit_transform(df[column])
     return df
 
-def sep(df_train, df_test):
-    X_train = df_train.iloc[:,1:-1]
-    y_train = df_train.iloc[:,-1]
-    X_test = df_test.iloc[:,1:-1]
-    y_test = df_test.iloc[:,-1]
+def sep(df_train, df_test, target_variable):
+    X_train = df_train.drop[target_variable]
+    y_train = df_train[target_variable]
+    X_test = df_test.drop[target_variable]
+    y_test = df_test[target_variable]
     return X_train, y_train, X_test, y_test
 
 def split(df):
